chardet: Universal encoding detector for Python 3
=================================================

Description
-----------

Universal encoding detector for Python 3

License
-------

LGPL

Upstream Contact
----------------

https://pypi.org/project/chardet/

